@@ -21,7 +21,6 @@ import sys
 import os
 from datetime import datetime
 from subprocess import *
-import psutil
 from requests_ntlm import HttpNtlmAuth
 from requests.auth import HTTPBasicAuth
 from requests.auth import HTTPDigestAuth
@@ -45,11 +44,17 @@ class Agent:
 # OS check
 #########################################################################################
 
-WINDOWS = psutil.WINDOWS
-LINUX = psutil.LINUX
-SUNOS = psutil.SUNOS
-FREEBSD = psutil.FREEBSD
-AIX = psutil.AIX
+POSIX = os.name == "posix"
+WINDOWS = os.name == "nt"
+LINUX = sys.platform.startswith("linux")
+MACOS = sys.platform.startswith("darwin")
+OSX = MACOS  # deprecated alias
+FREEBSD = sys.platform.startswith("freebsd")
+OPENBSD = sys.platform.startswith("openbsd")
+NETBSD = sys.platform.startswith("netbsd")
+BSD = FREEBSD or OPENBSD or NETBSD
+SUNOS = sys.platform.startswith(("sunos", "solaris"))
+AIX = sys.platform.startswith("aix")
 
 #########################################################################################
 # Timedate class
@@ -398,7 +403,39 @@ def parse_configuration(file="/etc/pandora/pandora_server.conf", separator=" "):
     except Exception as e:
         print (f"{type(e).__name__}: {e}")
 
+#########################################################################################
+# csv file parser
+#########################################################################################
+def parse_csv_file(file, separator=';', count_parameters=None, debug=False) -> list:
+    """
+    Parse csv configuration. Reads configuration file and stores its data in an array.
 
+    Args:
+    - file (str): configuration csv file path. \n
+    - separator (str, optional): Separator for option and value. Defaults to ";".
+    - coun_parameters (int): min number of parameters each line shold have. Default None
+    - debug: print errors on lines
+
+    Returns:
+    - arr: containing list whit all csv parameters.
+    """
+    csv_arr = []
+    try:
+        with open (file, "r") as conf:
+            lines = conf.read().splitlines()
+            for line in lines:
+                if line.startswith("#") or len(line) < 1 :
+                    continue
+                else:
+                    value = line.strip().split(separator)
+                    if count_parameters is None or len(value) >= count_parameters:
+                        csv_arr.append(value)
+                    elif debug==True: 
+                        print(f'Csv line: {line} doesnt match minimun parameter defined: {count_parameters}',file=sys.stderr)
+
+        return csv_arr
+    except Exception as e:
+        print (f"{type(e).__name__}: {e}")
 
 #########################################################################################
 # URL calls
@@ -458,9 +495,17 @@ def call_url(url, authtype, user, passw, time_out):
 
 
 #########################################################################################
-# Load required modules.  (No se si hara falta)
+# Translate macro
 #########################################################################################
+def translate_macros(macro_dic: dict, data: str)  -> str:
+    """Expects a macro dictionary key:value (macro_name:macro_value) 
+    and a string to replace macro. \n
+    It will replace the macro_name for the macro_value in any string.
+    """
+    for macro_name, macro_value in macro_dic.items():
+        data = data.replace(macro_name, macro_value) 
 
+    return data
 
 #########################################################################################
 # TEST
